Interface: LegendItem | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: LegendItem

## # Properties

### # borderRadius

• `Optional` borderRadius: `number` | `BorderRadius`

Border radius of the legend box

`since` 3.1.0

#### # Defined in

index.esm.d.ts:2174
(opens new window)

### # datasetIndex

• `Optional` datasetIndex: `number`

Index of the associated dataset

#### # Defined in

index.esm.d.ts:2179
(opens new window)

### # fillStyle

• `Optional` fillStyle: `Color`

Fill style of the legend box

#### # Defined in

index.esm.d.ts:2189
(opens new window)

### # fontColor

• `Optional` fontColor: `Color`

Font color for the text Defaults to LegendOptions.labels.color

#### # Defined in

index.esm.d.ts:2195
(opens new window)

### # hidden

• `Optional` hidden: `boolean`

If true, this item represents a hidden dataset. Label will be rendered with a strike-through effect

#### # Defined in

index.esm.d.ts:2200
(opens new window)

### # index

• `Optional` index: `number`

Index the associated label in the labels array

#### # Defined in

index.esm.d.ts:2184
(opens new window)

### # lineCap

• `Optional` lineCap: `CanvasLineCap`

For box border.

`see` https://developer.mozilla.org/en/docs/Web/API/CanvasRenderingContext2D/lineCap

#### # Defined in

index.esm.d.ts:2206
(opens new window)

### # lineDash

• `Optional` lineDash: `number`[]

For box border.

`see` https://developer.mozilla.org/en-US/docs/Web/API/CanvasRenderingContext2D/setLineDash

#### # Defined in

index.esm.d.ts:2212
(opens new window)

### # lineDashOffset

• `Optional` lineDashOffset: `number`

For box border.

`see` https://developer.mozilla.org/en-US/docs/Web/API/CanvasRenderingContext2D/lineDashOffset

#### # Defined in

index.esm.d.ts:2218
(opens new window)

### # lineJoin

• `Optional` lineJoin: `CanvasLineJoin`

For box border.

`see` https://developer.mozilla.org/en-US/docs/Web/API/CanvasRenderingContext2D/lineJoin

#### # Defined in

index.esm.d.ts:2224
(opens new window)

### # lineWidth

• `Optional` lineWidth: `number`

Width of box border

#### # Defined in

index.esm.d.ts:2229
(opens new window)

### # pointStyle

• `Optional` pointStyle: `PointStyle`

Point style of the legend box (only used if usePointStyle is true)

#### # Defined in

index.esm.d.ts:2239
(opens new window)

### # rotation

• `Optional` rotation: `number`

Rotation of the point in degrees (only used if usePointStyle is true)

#### # Defined in

index.esm.d.ts:2244
(opens new window)

### # strokeStyle

• `Optional` strokeStyle: `Color`

Stroke style of the legend box

#### # Defined in

index.esm.d.ts:2234
(opens new window)

### # text

• text: `string`

Label that will be displayed

#### # Defined in

index.esm.d.ts:2168
(opens new window)

### # textAlign

• `Optional` textAlign: `TextAlign`

Text alignment

#### # Defined in

index.esm.d.ts:2249
(opens new window)